@@ -22,7 +22,10 @@ class SignalType:
 NO_QUEUE = 'None'
 
 DEFAULT_DEAD_MESSAGE_TTL = 864000  # 10 days
-DEFAULT_DELAY_QUEUE_MAX_SIZE = None  # Infinite
-DEFAULT_CQRS_MESSAGE_TTL = 86400  # 1 day
-DEFAULT_CQRS_MAX_RETRIES = 30
-DEFAULT_CQRS_RETRY_DELAY = 2  # seconds
+
+DEFAULT_MASTER_AUTO_UPDATE_FIELDS = False
+DEFAULT_MASTER_MESSAGE_TTL = 86400  # 1 day
+
+DEFAULT_REPLICA_MAX_RETRIES = 30
+DEFAULT_REPLICA_RETRY_DELAY = 2  # seconds
+DEFAULT_REPLICA_DELAY_QUEUE_MAX_SIZE = 1000
