@@ -1,6 +1,6 @@
-#  Copyright © 2021 Ingram Micro Inc. All rights reserved.
+#  Copyright © 2022 Ingram Micro Inc. All rights reserved.
 
-from dj_cqrs.management.commands.utils import batch_qs
+from dj_cqrs.management.utils import batch_qs
 from dj_cqrs.registries import ReplicaRegistry
 
 from django.core.exceptions import FieldError
