@@ -21,8 +21,7 @@ class BaseTransport:
         """
         Send data from master model to replicas.
 
-        :param payload: Transport payload from master model.
-        :type payload: dj_cqrs.dataclasses.TransportPayload
+        :param dj_cqrs.dataclasses.TransportPayload payload: Transport payload from master model.
         """
         raise NotImplementedError
 
@@ -30,3 +29,8 @@ class BaseTransport:
     def consume(*args, **kwargs):
         """Receive data from master model."""
         raise NotImplementedError
+
+    @staticmethod
+    def clean_connection(*args, **kwargs):
+        """Clean transport connection. Here you can close all connections that you have"""
+        raise NotImplementedError
